@@ -14,7 +14,7 @@ use Exporter 'import';
 our @EXPORT =
   qw( $VERSION open_connections_SQLite close_connections_SQLite get_ontology);
 
-my @sqlites = qw(ncit icd10 ohdsi cdisc omim hpo);
+my @sqlites = qw(ncit icd10 ohdsi cdisc);
 my @matches = qw(exact_match full_text_search contains);
 use constant DEVEL_MODE => 0;
 
@@ -74,7 +74,7 @@ sub open_db_SQLite {
     my $path =
       ( $ontology eq 'ohdsi' && defined $path_to_ohdsi_db )
       ? $path_to_ohdsi_db
-      : catdir( $Convert::Pheno::share_dir, 'db' );
+      : catdir( $Convert::Pheno::lib_path, '../../db' );
     my $dbfile = catfile( $path, $filename );
     die "Sorry we could not find <$dbfile> file\n" unless -f $dbfile;
 
@@ -267,12 +267,6 @@ sub execute_query_SQLite {
     my $ontology                  = $arg->{ontology};
     my $match                     = $arg->{match};
 
-    # set $id and $label to undef
-    my ($id, $label) = (undef, undef);
-
-    # Premature return if $query eq '' 
-    return ($id, $label) if $query eq '';
-
 #  Columns in DBs
 #     *<ncit.db>, <icd10.db> and <cdisc.db> were pre-processed to have "id" and "label" columns only
 #       label [0]
@@ -287,7 +281,7 @@ sub execute_query_SQLite {
     # Define a hash for column position on databases
     # We may encounter a situation where order of columns is different
     my $position = {};
-    $position->{$_} = { label => 0, id => 1 } for (@sqlites);
+    $position->{$_} = { label => 0, id => 1 } for (qw/ncit icd10 cdisc ohdsi/);
     my $id_column    = $position->{$ontology}{id};
     my $label_column = $position->{$ontology}{label};
 
@@ -300,15 +294,18 @@ sub execute_query_SQLite {
 
     # NB: Order matters in the changes below
     $query =~ s/^\d+\s+\-\s+//;                            # for ALL SEARCHES!!!
-    $query =~ tr#_,-/# # if $match eq 'full_text_search';   # FTS
+    $query =~ tr/_,-/ / if $match eq 'full_text_search';   # FTS
     $query =~
-      tr/ //s;    # remove duplicated spaces            # for ALL SEARCHES!!!
+      tr/ //s;    # remove duplicate spaces            # for ALL SEARCHES!!!
 
     # Execute query
     $sth->bind_param( 1, $query )
       ;           # docstore.mik.ua/orelly/linux/dbi/ch05_03.htm
     $sth->execute();    # eq to $sth->execute($query);
 
+    my $id    = undef;
+    my $label = undef;
+
     if ( $match eq 'exact_match' ) {
 
         # Parse query
